@@ -1,6 +1,6 @@
 """Housekeeper models"""
+
 from datetime import datetime
-from typing import List, Optional
 
 from pydantic import BaseModel
 
@@ -8,11 +8,11 @@ from pydantic import BaseModel
 class InputFile(BaseModel):
     path: str
     archive: bool = False
-    tags: List[str]
+    tags: list[str]
 
 
 class InputBundle(BaseModel):
     name: str
     created: datetime = datetime.now()
-    expires: Optional[datetime]
-    files: List[InputFile]
+    expires: datetime | None = None
+    files: list[InputFile]
