@@ -1,6 +1,8 @@
 """Constants specific for encryption"""
 
-from cg.utils.enums import ListEnum, StrEnum
+from enum import StrEnum
+
+from cg.utils.enums import ListEnum
 
 
 class CipherAlgorithm(StrEnum):
@@ -18,25 +20,28 @@ class CipherAlgorithm(StrEnum):
 
 
 class EncryptionUserID(StrEnum):
-    HASTA_USER_ID: str = "Clinical Genomics"
+    HASTA_USER_ID: str = '"Clinical Genomics"'
 
 
 class GPGParameters(ListEnum):
-    ASYMMETRIC_ENCRYPTION: list = [
+    ASYMMETRIC_ENCRYPTION: list[str] = [
         "--encrypt",
+        "--yes",
         "--recipient",
         EncryptionUserID.HASTA_USER_ID,
     ]
     ASYMMETRIC_DECRYPTION: list = [
         "--decrypt",
+        "--yes",
         "--batch",
         "--cipher-algo",
         CipherAlgorithm.AES256,
         "--passphrase",
         EncryptionUserID.HASTA_USER_ID,
     ]
-    SYMMETRIC_ENCRYPTION: list = [
+    SYMMETRIC_ENCRYPTION: list[str] = [
         "--symmetric",
+        "--yes",
         "--cipher-algo",
         CipherAlgorithm.AES256,
         "--batch",
@@ -44,13 +49,14 @@ class GPGParameters(ListEnum):
         "None",
         "--passphrase-file",
     ]
-    SYMMETRIC_DECRYPTION: list = [
+    SYMMETRIC_DECRYPTION: list[str] = [
         "--decrypt",
+        "--yes",
         "--cipher-algo",
         CipherAlgorithm.AES256,
         "--batch",
         "--passphrase-file",
     ]
-    OUTPUT_PARAMETER: list = [
+    OUTPUT_PARAMETER: list[str] = [
         "-o",
     ]
