@@ -19,7 +19,12 @@ LOQUSDB_CANCER_CUSTOMERS = [
     CustomerId.CUST143,
     CustomerId.CUST147,
 ]
-LOQUSDB_LONG_READ_CUSTOMERS = [CustomerId.CUST002, CustomerId.CUST003, CustomerId.CUST004]
+LOQUSDB_LONG_READ_CUSTOMERS = [
+    CustomerId.CUST002,
+    CustomerId.CUST003,
+    CustomerId.CUST004,
+    CustomerId.CUST201,
+]
 LOQUSDB_LONG_READ_SEQUENCING_METHODS = [
     SeqLibraryPrepCategory.WHOLE_GENOME_SEQUENCING,
 ]
