@@ -60,6 +60,12 @@ class BalsamicStartError(CgError):
     """
 
 
+class BedVersionNotFoundError(CgError):
+    """
+    Exception raised when a bed version is not found.
+    """
+
+
 class BundleAlreadyAddedError(CgError):
     """
     Exception raised when a bundle has already been added to Housekeeper.
@@ -328,5 +334,5 @@ class Chanjo2ResponseError(Chanjo2APIClientError):
     """Exception raised when the response from Chanjo2 API client fails validation."""
 
 
-class CaseNotConfiguredError(CgError):
-    """Exception raised when a case is being run without a configuration."""
+class MissingConfigFilesError(CgError):
+    """Exception raised when a case is being run with missing configuration files."""
