@@ -1,8 +1,7 @@
+import json
 from pathlib import Path
 from typing import Any
 
-import json
-
 
 def read_json(file_path: Path) -> Any:
     """Read content in a json file"""
@@ -18,7 +17,7 @@ def read_json_stream(stream: str) -> Any:
 def write_json(content: Any, file_path: Path) -> None:
     """Write content to a json file"""
     with open(file_path, "w") as file:
-        json.dump(content, file)
+        json.dump(content, file, indent=4)
 
 
 def write_json_stream(content: Any) -> str:
