@@ -3,8 +3,7 @@
 import logging
 from subprocess import CalledProcessError
 
-import click
-
+import rich_click as click
 
 from cg.cli.upload.scout import upload_rna_to_scout
 from cg.constants import DataDelivery
@@ -25,7 +24,7 @@ class MipRNAUploadAPI(UploadAPI):
 
     def upload(self, ctx: click.Context, case: Case, restart: bool) -> None:
         """Uploads MIP-RNA analysis data and files."""
-        analysis: Analysis = case.analyses[0]
+        analysis: Analysis = self.status_db.get_latest_completed_analysis_for_case(case.internal_id)
         self.update_upload_started_at(analysis=analysis)
 
         self.upload_files_to_customer_inbox(case=case)
