@@ -214,12 +214,24 @@ class FluffyAnalysisAPI(AnalysisAPI):
         sample_sheet_content: list[list[str]] = ReadFile.get_content_from_file(
             file_format=FileFormat.CSV, file_path=sample_sheet_path
         )
-        samples: list[IlluminaSampleIndexSetting] = get_samples_from_content(sample_sheet_content)
+        flow_cell_samples: list[IlluminaSampleIndexSetting] = get_samples_from_content(
+            sample_sheet_content
+        )
+        case_db_sample_ids: list[str] = [
+            sample.internal_id for sample in self.status_db.get_samples_by_case_id(case_id=case_id)
+        ]
+        nipt_samples: list[IlluminaSampleIndexSetting] = []
+        for sample in flow_cell_samples:
+            if sample.sample_id in case_db_sample_ids:
+                LOG.debug(f"Using NIPT sample {sample.sample_id} for Fluffy sample sheet")
+                nipt_samples.append(sample)
+            else:
+                LOG.debug(f"Sample {sample.sample_id} does not belong to case {case_id}, skipping")
 
         if not dry_run:
             Path(self.root_dir, case_id).mkdir(parents=True, exist_ok=True)
             fluffy_sample_sheet: FluffySampleSheet = self.create_fluffy_sample_sheet(
-                samples=samples,
+                samples=nipt_samples,
                 flow_cell_id=sequencing_run.device.internal_id,
             )
 
