@@ -5,12 +5,17 @@ from pathlib import Path
 
 from cg.constants import Workflow
 from cg.constants.constants import GenomeVersion
-from cg.constants.nf_analysis import MULTIQC_NEXFLOW_CONFIG
 from cg.constants.sequencing import SequencingPlatform
 from cg.constants.symbols import EMPTY_STRING
 from cg.meta.workflow.nf_analysis import NfAnalysisAPI
+from cg.models.analysis import NextflowAnalysis
 from cg.models.cg_config import CGConfig
-from cg.models.taxprofiler.taxprofiler import TaxprofilerParameters, TaxprofilerSampleSheetEntry
+from cg.models.deliverables.metric_deliverables import MetricsBase
+from cg.models.taxprofiler.taxprofiler import (
+    TaxprofilerParameters,
+    TaxprofilerQCMetrics,
+    TaxprofilerSampleSheetEntry,
+)
 from cg.resources import TAXPROFILER_BUNDLE_FILENAMES_PATH
 from cg.store.models import CaseSample, Sample
 
@@ -28,13 +33,15 @@ class TaxprofilerAnalysisAPI(NfAnalysisAPI):
     ):
         super().__init__(config=config, workflow=workflow)
         self.root_dir: str = config.taxprofiler.root
-        self.nfcore_workflow_path: str = config.taxprofiler.workflow_path
+        self.workflow_bin_path: str = config.taxprofiler.workflow_bin_path
+        self.profile: str = config.taxprofiler.profile
         self.conda_env: str = config.taxprofiler.conda_env
         self.conda_binary: str = config.taxprofiler.conda_binary
-        self.profile: str = config.taxprofiler.profile
+        self.platform: str = config.taxprofiler.platform
+        self.params: str = config.taxprofiler.params
+        self.workflow_config_path: str = config.taxprofiler.config
+        self.resources: str = config.taxprofiler.resources
         self.revision: str = config.taxprofiler.revision
-        self.hostremoval_reference: Path = Path(config.taxprofiler.hostremoval_reference)
-        self.databases: Path = Path(config.taxprofiler.databases)
         self.tower_binary_path: str = config.tower_binary_path
         self.tower_workflow: str = config.taxprofiler.tower_workflow
         self.account: str = config.taxprofiler.slurm.account
@@ -47,20 +54,11 @@ class TaxprofilerAnalysisAPI(NfAnalysisAPI):
         """Headers for sample sheet."""
         return TaxprofilerSampleSheetEntry.headers()
 
-    @property
-    def is_params_appended_to_nextflow_config(self) -> bool:
-        """Return True if parameters should be added into the nextflow config file instead of the params file."""
-        return False
-
     @property
     def is_multiqc_pattern_search_exact(self) -> bool:
         """Only exact pattern search is allowed to collect metrics information from multiqc file."""
         return True
 
-    def get_nextflow_config_content(self, case_id: str) -> str:
-        """Return nextflow config content."""
-        return MULTIQC_NEXFLOW_CONFIG
-
     @staticmethod
     def get_bundle_filenames_path() -> Path:
         """Return Taxprofiler bundle filenames path."""
@@ -82,15 +80,13 @@ class TaxprofilerAnalysisAPI(NfAnalysisAPI):
         )
         return sample_sheet_entry.reformat_sample_content()
 
-    def get_workflow_parameters(self, case_id: str) -> TaxprofilerParameters:
+    def get_built_workflow_parameters(
+        self, case_id: str, dry_run: bool = False
+    ) -> TaxprofilerParameters:
         """Return Taxprofiler parameters."""
         return TaxprofilerParameters(
-            cluster_options=f"--qos={self.get_slurm_qos_for_case(case_id=case_id)}",
             input=self.get_sample_sheet_path(case_id=case_id),
             outdir=self.get_case_path(case_id=case_id),
-            databases=self.databases,
-            hostremoval_reference=self.hostremoval_reference,
-            priority=self.account,
         )
 
     def get_multiqc_search_patterns(self, case_id: str) -> dict:
@@ -104,3 +100,10 @@ class TaxprofilerAnalysisAPI(NfAnalysisAPI):
     def get_genome_build(self, case_id: str) -> str:
         """Return the reference genome build version of a Taxprofiler analysis."""
         return GenomeVersion.T2T_CHM13.value
+
+    def parse_analysis(self, qc_metrics_raw: list[MetricsBase], **kwargs) -> NextflowAnalysis:
+        """Parse Nextflow output analysis files and return an analysis model."""
+        qc_metrics_model = TaxprofilerQCMetrics
+        return super().parse_analysis(
+            qc_metrics_raw=qc_metrics_raw, qc_metrics_model=qc_metrics_model, **kwargs
+        )
