@@ -4,7 +4,6 @@ from pathlib import Path
 from cg.apps.lims import LimsAPI
 from cg.constants import FileExtensions
 from cg.constants.scout import ScoutExportFileName
-from cg.constants.symbols import EMPTY_STRING
 from cg.exc import CgDataError
 from cg.io.csv import write_csv
 from cg.io.yaml import read_yaml, write_yaml_nextflow_style
@@ -30,11 +29,10 @@ class RarediseaseParamsFileCreator(ParamsFileCreator):
         self.store = store
         self.lims = lims
 
-    def create(self, case_id: str, case_path: Path, sample_sheet_path: Path) -> None:
+    def create(self, case_id: str, file_path: Path, sample_sheet_path: Path) -> None:
         LOG.debug(f"Creating params file for case {case_id}")
-        file_path: Path = self.get_file_path(case_id=case_id, case_path=case_path)
         content: dict = self._get_content(
-            case_id=case_id, case_path=case_path, sample_sheet_path=sample_sheet_path
+            case_id=case_id, case_path=file_path.parent, sample_sheet_path=sample_sheet_path
         )
         write_yaml_nextflow_style(file_path=file_path, content=content)
 
@@ -44,8 +42,7 @@ class RarediseaseParamsFileCreator(ParamsFileCreator):
             case_id=case_id, case_path=case_path, sample_sheet_path=sample_sheet_path
         ).model_dump()
         workflow_parameters: dict = read_yaml(self.params)
-        duplicate_keys = set(case_parameters.keys()) & set(workflow_parameters.keys())
-        if duplicate_keys:
+        if duplicate_keys := set(case_parameters.keys()) & set(workflow_parameters.keys()):
             raise CgDataError(f"Duplicate parameter keys found: {duplicate_keys}")
         parameters: dict = case_parameters | workflow_parameters
         curated_parameters: dict = replace_values_in_params_file(parameters)
@@ -55,7 +52,7 @@ class RarediseaseParamsFileCreator(ParamsFileCreator):
         self, case_id: str, case_path: Path, sample_sheet_path: Path
     ) -> RarediseaseParameters:
         """Return case-specific parameters for the analysis."""
-        analysis_type: str = self._get_data_analysis_type(case_id)
+        analysis_type: str = self._get_arbitrary_prep_category_in_case(case_id)
         target_bed_file: str = self._get_target_bed_from_lims(case_id)
         sample_mapping_file: Path = self._create_sample_mapping_file(
             case_id=case_id, case_path=case_path
@@ -71,13 +68,13 @@ class RarediseaseParamsFileCreator(ParamsFileCreator):
             sample_id_map=sample_mapping_file,
         )
 
-    def _get_data_analysis_type(self, case_id: str) -> str:
+    def _get_arbitrary_prep_category_in_case(self, case_id: str) -> str:
         """
-        Return case analysis type (WEG, WGS, WTS or TGS). Assumes all case samples have the same
-        analysis type.
+        Returns prep category. Assumes all case samples have the same
+        prep category.
         """
         sample: Sample = self.store.get_samples_by_case_id(case_id=case_id)[0]
-        return sample.application_version.application.analysis_type
+        return sample.prep_category
 
     def _get_target_bed_from_lims(self, case_id: str) -> str:
         """
@@ -85,18 +82,14 @@ class RarediseaseParamsFileCreator(ParamsFileCreator):
         Raises:
             CgDataError: if the bed target capture version is not found in StatusDB.
         """
-        case: Case = self.store.get_case_by_internal_id(internal_id=case_id)
+        case: Case = self.store.get_case_by_internal_id_strict(internal_id=case_id)
         sample: Sample = case.samples[0]
-        if sample.from_sample:
-            sample: Sample = self.store.get_sample_by_internal_id(internal_id=sample.from_sample)
-        target_bed_shortname: str | None = self.lims.capture_kit(lims_id=sample.internal_id)
-        if not target_bed_shortname:
-            return EMPTY_STRING
-        bed_version: BedVersion | None = self.store.get_bed_version_by_short_name(
-            bed_version_short_name=target_bed_shortname
+        target_bed_shortname: str = self.lims.get_capture_kit_strict(
+            sample.from_sample or sample.internal_id
+        )
+        bed_version: BedVersion = self.store.get_bed_version_by_short_name_strict(
+            target_bed_shortname
         )
-        if not bed_version:
-            raise CgDataError(f"Bed-version {target_bed_shortname} does not exist")
         return bed_version.filename
 
     def _create_sample_mapping_file(self, case_id: str, case_path: Path) -> Path:
@@ -105,8 +98,7 @@ class RarediseaseParamsFileCreator(ParamsFileCreator):
             FileExtensions.CSV
         )
         content: list[list[str]] = [["customer_id", "internal_id"]]
-        case: Case = self.store.get_case_by_internal_id(internal_id=case_id)
-        for sample in case.samples:
-            content.append([sample.name, sample.internal_id])
+        case: Case = self.store.get_case_by_internal_id_strict(internal_id=case_id)
+        content.extend([sample.name, sample.internal_id] for sample in case.samples)
         write_csv(file_path=file_path, content=content)
         return file_path
