@@ -1,6 +1,6 @@
 from pathlib import Path
 
-from cg.exc import CaseNotConfiguredError
+from cg.exc import MissingConfigFilesError
 from cg.models.cg_config import CommonAppConfig
 from cg.services.analysis_starter.configurator.configurator import Configurator
 from cg.services.analysis_starter.configurator.extensions.abstract import PipelineExtension
@@ -45,17 +45,20 @@ class NextflowConfigurator(Configurator):
         3. Creating a parameters file.
         4. Creating a configuration file.
         5. Creating any pipeline specific files."""
-        case_path: Path = self._get_case_path(case_id)
+        case_run_directory: Path = self._get_case_run_directory(case_id)
+        sample_sheet_path: Path = self._get_sample_sheet_path(case_id)
+        params_file_path: Path = self._get_params_file_path(case_id)
+        config_file_path: Path = self._get_config_file_path(case_id)
+
         self._create_case_directory(case_id)
-        self.sample_sheet_creator.create(case_id=case_id, case_path=case_path)
-        sample_sheet_path: Path = self.sample_sheet_creator.get_file_path(
-            case_id=case_id, case_path=case_path
-        )
+        self.sample_sheet_creator.create(case_id=case_id, file_path=sample_sheet_path)
         self.params_file_creator.create(
-            case_id=case_id, case_path=case_path, sample_sheet_path=sample_sheet_path
+            case_id=case_id,
+            file_path=params_file_path,
+            sample_sheet_path=sample_sheet_path,
         )
-        self.config_file_creator.create(case_id=case_id, case_path=case_path)
-        self.pipeline_extension.configure(case_id=case_id, case_path=case_path)
+        self.config_file_creator.create(case_id=case_id, file_path=config_file_path)
+        self.pipeline_extension.configure(case_id=case_id, case_run_directory=case_run_directory)
         return self.get_config(case_id=case_id, **flags)
 
     def get_config(self, case_id: str, **flags) -> NextflowCaseConfig:
@@ -64,13 +67,8 @@ class NextflowConfigurator(Configurator):
         Raises:
             CaseNotConfiguredError if the params file or config file does not exist.
         """
-        case_path: Path = self._get_case_path(case_id=case_id)
-        params_file_path: Path = self.params_file_creator.get_file_path(
-            case_id=case_id, case_path=case_path
-        )
-        config_file_path: Path = self.config_file_creator.get_file_path(
-            case_id=case_id, case_path=case_path
-        )
+        params_file_path: Path = self._get_params_file_path(case_id=case_id)
+        config_file_path: Path = self._get_config_file_path(case_id=case_id)
         config = NextflowCaseConfig(
             case_id=case_id,
             case_priority=self.store.get_case_priority(case_id),
@@ -84,27 +82,52 @@ class NextflowConfigurator(Configurator):
             workflow=self.store.get_case_workflow(case_id),
         )
         config: NextflowCaseConfig = self._set_flags(config=config, **flags)
-        self._ensure_valid_config(config)
+        self._ensure_required_config_files_exist(config)
         return config
 
-    def _get_case_path(self, case_id: str) -> Path:
+    def _get_config_file_path(self, case_id: str) -> Path:
+        """Return the path to the Nextflow config file."""
+        return Path(self._get_case_run_directory(case_id), f"{case_id}_nextflow_config.json")
+
+    def _get_params_file_path(self, case_id: str) -> Path:
+        """Return the path to the params file for a case."""
+        return Path(self._get_case_run_directory(case_id), f"{case_id}_params_file.yaml")
+
+    def _get_sample_sheet_path(self, case_id: str) -> Path:
+        return Path(self._get_case_run_directory(case_id), f"{case_id}_samplesheet.csv")
+
+    def _get_case_run_directory(self, case_id: str) -> Path:
         """Path to case working directory."""
         return Path(self.root_dir, case_id)
 
     def _create_case_directory(self, case_id: str) -> None:
         """Create case working directory."""
-        case_path: Path = self._get_case_path(case_id=case_id)
+        case_path: Path = self._get_case_run_directory(case_id=case_id)
         case_path.mkdir(parents=True, exist_ok=True)
 
     def _get_work_dir(self, case_id: str) -> Path:
         return Path(self.root_dir, case_id, "work")
 
-    @staticmethod
-    def _ensure_valid_config(config: NextflowCaseConfig) -> None:
+    def _ensure_required_config_files_exist(self, config: NextflowCaseConfig) -> None:
+        """
+        Ensure that the config and the params files exists.
+        Raises:
+            MissingConfigFilesError if either the params file or the config file is missing.
+        """
         params_file_path = Path(config.params_file)
         config_file_path = Path(config.nextflow_config_file)
-        if not params_file_path.exists() or not config_file_path.exists():
-            raise CaseNotConfiguredError(
-                f"Please ensure that both the parameters file {params_file_path.as_posix()} "
-                f"and the configuration file {config_file_path.as_posix()} exists."
+        samplesheet_file_path: Path = self._get_sample_sheet_path(config.case_id)
+        if not (
+            self.pipeline_extension.do_required_files_exist(
+                case_run_directory=self._get_case_run_directory(config.case_id)
+            )
+            and params_file_path.exists()
+            and config_file_path.exists()
+            and samplesheet_file_path.exists()
+        ):
+            raise MissingConfigFilesError(
+                f"Please ensure that the parameters file {params_file_path.as_posix()}, "
+                f"the configuration file {config_file_path.as_posix()}, "
+                f"the sample sheet {samplesheet_file_path.as_posix()}, and "
+                f"all pipeline specific files exists."
             )
