@@ -1,5 +1,8 @@
 from cg.services.delivery_message.messages.delivery_message import DeliveryMessage
-from cg.services.delivery_message.messages.utils import get_caesar_delivery_path
+from cg.services.delivery_message.messages.utils import (
+    REMINDER_TO_DOWNLOAD_MESSAGE,
+    get_caesar_delivery_path,
+)
 from cg.store.models import Case
 
 
@@ -10,5 +13,6 @@ class MicrosaltMwxMessage(DeliveryMessage):
             f"Hello,\n\n"
             f"The analysis is now complete and the fastq files are being uploaded to:\n\n"
             f"{delivery_path} \n\n"
-            "The QC report can be found attached."
+            "The QC report can be found attached. \n\n"
+            f"{REMINDER_TO_DOWNLOAD_MESSAGE}"
         )
