@@ -1,5 +1,9 @@
 from cg.services.delivery_message.messages.delivery_message import DeliveryMessage
-from cg.services.delivery_message.messages.utils import get_caesar_delivery_path, get_scout_link
+from cg.services.delivery_message.messages.utils import (
+    REMINDER_TO_DOWNLOAD_MESSAGE,
+    get_caesar_delivery_path,
+    get_scout_link,
+)
 from cg.store.models import Case
 
 
@@ -11,7 +15,8 @@ def get_case_message(case: Case) -> str:
         "The analysis has been uploaded to Scout for the following case:\n\n"
         f"{scout_link}\n\n"
         "The raw data files are currently being uploaded to your inbox on Caesar:\n\n"
-        f"{delivery_path}"
+        f"{delivery_path} \n\n"
+        f"{REMINDER_TO_DOWNLOAD_MESSAGE}"
     )
 
 
@@ -24,7 +29,8 @@ def get_cases_message(cases: list[Case]) -> str:
         "The analyses have been uploaded to Scout for the following cases:\n\n"
         f"{scout_links_row_separated}\n\n"
         "The raw data files are currently being uploaded to your inbox on Caesar:\n\n"
-        f"{delivery_path}"
+        f"{delivery_path} \n\n"
+        f"{REMINDER_TO_DOWNLOAD_MESSAGE}"
     )
 
 
