@@ -2,15 +2,14 @@ from pydantic import BeforeValidator, Field, PrivateAttr
 from typing_extensions import Annotated
 
 from cg.models.orders.sample_base import ControlEnum, PriorityEnum
-from cg.services.orders.validation.constants import ElutionBuffer, ExtractionMethod
+from cg.services.orders.validation.constants import ElutionBuffer
 from cg.services.orders.validation.models.sample import Sample
-from cg.services.orders.validation.utils import parse_buffer, parse_control, parse_extraction_method
+from cg.services.orders.validation.utils import parse_buffer, parse_control
 
 
 class MicrosaltSample(Sample):
     control: Annotated[ControlEnum, BeforeValidator(parse_control)] = ControlEnum.not_control
     elution_buffer: Annotated[ElutionBuffer, BeforeValidator(parse_buffer)]
-    extraction_method: Annotated[ExtractionMethod, BeforeValidator(parse_extraction_method)]
     organism: str
     organism_other: str | None = None
     priority: PriorityEnum
