@@ -2,7 +2,7 @@ import logging
 from pathlib import Path
 
 from cg.io.controller import ReadFile
-from cg.utils.files import get_file_in_directory, get_files_in_directory_with_pattern
+from cg.utils.files import get_file_in_directory
 
 LOG = logging.getLogger(__name__)
 
@@ -59,10 +59,6 @@ class ValidateFileTransferService:
         except FileNotFoundError:
             return False
 
-    @staticmethod
-    def _get_manifest_file_paths(source_dir: Path, pattern: str) -> list[Path]:
-        return get_files_in_directory_with_pattern(directory=source_dir, pattern=pattern)
-
     def _get_files_in_manifest(self, manifest_file: Path, manifest_file_format: str) -> list[str]:
         """Get the files listed in the manifest file."""
         manifest_content: list[str] = self._get_manifest_file_content(
