@@ -5,6 +5,7 @@ import logging
 from datetime import datetime
 from typing import Callable, Iterator
 
+import sqlalchemy
 from sqlalchemy.orm import Query
 
 from cg.constants import SequencingRunDataAvailability, Workflow
@@ -14,6 +15,7 @@ from cg.constants.sequencing import DNA_PREP_CATEGORIES, SeqLibraryPrepCategory
 from cg.exc import (
     AnalysisDoesNotExistError,
     AnalysisNotCompletedError,
+    BedVersionNotFoundError,
     CaseNotFoundError,
     CgDataError,
     CgError,
@@ -759,6 +761,25 @@ class ReadHandler(BaseHandler):
             internal_id=internal_id,
         ).first()
 
+    def get_case_by_internal_id_strict(self, internal_id: str) -> Case:
+        """
+        Get case by internal id.
+        Raises:
+            CaseNotFoundError: If no case is found with the given internal id.
+            sqlalchemy.orm.exc.MultipleResultsFound: If multiple cases are found with the same
+            internal id. This should not happen due to database constraints.
+        """
+        try:
+            return apply_case_filter(
+                cases=self._get_query(table=Case),
+                filter_functions=[CaseFilter.BY_INTERNAL_ID],
+                internal_id=internal_id,
+            ).one()
+        except sqlalchemy.orm.exc.NoResultFound:
+            raise CaseNotFoundError(
+                f"Case with internal id {internal_id} was not found in the database."
+            )
+
     def get_cases_by_internal_ids(self, internal_ids: list[str]) -> list[Case]:
         """Get cases by internal ids."""
         return apply_case_filter(
@@ -882,15 +903,14 @@ class ReadHandler(BaseHandler):
             valid_from=dt.datetime.now(),
         ).first()
 
-    def get_active_applications_by_prep_category(
+    def get_applications_by_prep_category(
         self, prep_category: SeqLibraryPrepCategory
     ) -> list[Application]:
-        """Return all active applications by prep category."""
+        """Return all applications by prep category."""
         return apply_application_filter(
             applications=self._get_query(table=Application),
             filter_functions=[
                 ApplicationFilter.BY_PREP_CATEGORIES,
-                ApplicationFilter.IS_NOT_ARCHIVED,
             ],
             prep_categories=[prep_category],
         ).all()
@@ -911,6 +931,25 @@ class ReadHandler(BaseHandler):
             filter_functions=[BedVersionFilter.BY_SHORT_NAME],
         ).first()
 
+    def get_bed_version_by_short_name_strict(self, short_name: str) -> BedVersion:
+        """
+        Return bed version with short name.
+        Raises:
+            BedVersionNotFoundError: If no bed version is found with the given short name.
+            sqlalchemy.orm.exc.MultipleResultsFound: If multiple bed versions are found with the same
+            shortname.
+        """
+        try:
+            return apply_bed_version_filter(
+                bed_versions=self._get_query(table=BedVersion),
+                bed_version_short_name=short_name,
+                filter_functions=[BedVersionFilter.BY_SHORT_NAME],
+            ).one()
+        except sqlalchemy.orm.exc.NoResultFound:
+            raise BedVersionNotFoundError(
+                f"Bed version with short name {short_name} was not found in the database."
+            )
+
     def get_bed_by_entry_id(self, bed_entry_id: int) -> Bed:
         """Get panel bed with bed entry id."""
         return apply_bed_filter(
@@ -1159,14 +1198,14 @@ class ReadHandler(BaseHandler):
         ).all()
 
     def get_analyses_to_clean(
-        self, before: datetime = datetime.now(), workflow: Workflow | None = None
+        self, before: datetime, workflow: Workflow | None = None
     ) -> list[Analysis]:
         """Return analyses that haven't been cleaned."""
         filter_functions: list[Callable] = [
             AnalysisFilter.COMPLETED,
             AnalysisFilter.IS_UPLOADED,
             AnalysisFilter.IS_NOT_CLEANED,
-            AnalysisFilter.STARTED_AT_BEFORE,
+            AnalysisFilter.COMPLETED_AT_BEFORE,
             AnalysisFilter.CASE_ACTION_IS_NONE,
         ]
         if workflow:
@@ -1175,7 +1214,7 @@ class ReadHandler(BaseHandler):
             filter_functions=filter_functions,
             analyses=self._get_latest_analyses_for_cases_query(),
             workflow=workflow,
-            started_at_date=before,
+            completed_at_date=before,
         ).all()
 
     def get_completed_analyses_for_workflow_started_at_before(
